<img src="https://user-images.githubusercontent.com/21954664/156930990-0d668468-0cd9-496e-995a-96d2c2407cf5.png" alt="ehrapy logo">

ehrapy is a modular open-source Python framework designed for exploratory end-to-end analysis of heterogeneous epidemiology and electronic health record data.

```{eval-rst}
.. card:: Installation :octicon:`plug;1em;`
    :link: installation
    :link-type: doc

    New to *ehrapy*? Check out the installation guide.
```

```{eval-rst}
.. card:: API reference :octicon:`book;1em;`
    :link: usage/usage
    :link-type: doc

    The API reference contains a detailed description of the ehrapy API.
```

```{eval-rst}
.. card:: Tutorials :octicon:`play;1em;`
    :link: tutorials/index
    :link-type: doc

    The tutorials walk you through real-world applications of ehrapy.
```

```{eval-rst}
.. card:: Use cases :octicon:`info;1em;`
    :link: user_guide/index
    :link-type: doc

    ehrapy has been applied to many use-cases. We highlight some of them here.
    Interested in adding your use-case? Please talk to us.
```

```{eval-rst}
.. card:: Discussion :octicon:`megaphone;1em;`
    :link: https://discourse.scverse.org/

    Need help? Reach out on our forum to get your questions answered!

```

```{eval-rst}
.. card:: GitHub :octicon:`mark-github;1em;`
    :link: https://github.com/theislab/ehrapy

    Find a bug? Interested in improving ehrapy? Checkout our GitHub for the latest developments.

```

```{toctree}
:caption: 'Contents:'
:hidden: true
:maxdepth: 3

installation
usage/usage
tutorials/index
contributing
code_of_conduct
Discussions <https://github.com/theislab/ehrapy/discussions>
authors
references
```

# Citation

[Exploratory electronic health record analysis with ehrapy Lukas Heumos, Philipp Ehmele, Tim Treis, Julius Upmeier zu Belzen, Altana Namsaraeva, Nastassya Horlava, Vladimir A. Shitov, Xinyue Zhang, Luke Zappia, Rainer Knoll, Niklas J. Lang, Leon Hetzel, Isaac Virshup, Lisa Sikkema, Eljas Roellin, Fabiola Curion, Roland Eils, Herbert B. Schiller, Anne Hilgendorff, Fabian J. Theis
medRxiv 2023.12.11.23299816; doi: https://doi.org/10.1101/2023.12.11.23299816 ](https://www.medrxiv.org/content/10.1101/2023.12.11.23299816v1).

# Indices and tables

-   {ref}`genindex`
-   {ref}`modindex`
-   {ref}`search`

[scanpy genome biology (2018)]: https://doi.org/10.1186/s13059-017-1382-0
